==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/eb/eba8fce710be7cf64fc9e233a3e72866.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Entity/UpsertInterface.php */
class __TwigTemplate_8328f6a0835a5250e891e85231f7dcc7 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\CoreBundle\\Entity;

interface UpsertInterface
{
    public const ROWS_AFFECTED_ON_INSERT = 1;

    public const ROWS_AFFECTED_ON_UPDATE = 2;

    public function hasBeenInserted(): bool;

    public function hasBeenUpdated(): bool;

    public function setHasBeenUpdated(bool \$hasBeenUpdated): void;

    public function setHasBeenInserted(bool \$hasBeenInserted): void;
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Entity/UpsertInterface.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Entity/UpsertInterface.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Entity/UpsertInterface.php");
    }
}

==> production-demo-20260214_152721.tar.gz: var/www/html/production-demo/var/tmp/twig/eb/eba8fce710be7cf64fc9e233a3e72866.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Entity/UpsertInterface.php */
class __TwigTemplate_8328f6a0835a5250e891e85231f7dcc7 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\CoreBundle\\Entity;

interface UpsertInterface
{
    public const ROWS_AFFECTED_ON_INSERT = 1;

    public const ROWS_AFFECTED_ON_UPDATE = 2;

    public function hasBeenInserted(): bool;

    public function hasBeenUpdated(): bool;

    public function setHasBeenUpdated(bool \$hasBeenUpdated): void;

    public function setHasBeenInserted(bool \$hasBeenInserted): void;
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Entity/UpsertInterface.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Entity/UpsertInterface.php", "/var/www/html/production-demo/app/bundles/CoreBundle/Entity/UpsertInterface.php");
    }
}
